@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.79';
+our $VERSION = '0.80';
 
 use Dist::Zilla 6.0;
 
@@ -300,6 +300,7 @@ sub _build_plugins {
         'MAXMIND::License',
         $self->_release_check_plugins,
         'MAXMIND::TidyAll',
+        $self->_upload_to_cpan_plugin,
         $self->_git_plugins,
     ];
 }
@@ -350,7 +351,6 @@ sub _basic_plugins {
         CheckVersionIncrement
         TestRelease
         ConfirmRelease
-        UploadToCPAN
         MAXMIND::VersionProvider
     );
 }
@@ -742,6 +742,12 @@ sub _release_check_plugins {
     );
 }
 
+sub _upload_to_cpan_plugin {
+    return [
+        UploadToCPAN => { pause_cfg_file => '.pause-maxmind' },
+    ];
+}
+
 sub _git_plugins {
     my $self = shift;
 
@@ -816,7 +822,7 @@ Dist::Zilla::PluginBundle::MAXMIND - MAXMIND's plugin bundle
 
 =head1 VERSION
 
-version 0.79
+version 0.80
 
 =head1 SYNOPSIS
 
@@ -1096,30 +1102,13 @@ This is more or less equivalent to the following F<dist.ini>:
 
 Bugs may be submitted through L<https://github.com/maxmind/Dist-Zilla-PluginBundle-MAXMIND/issues>.
 
-=head1 DONATIONS
-
-If you'd like to thank me for the work I've done on this module, please
-consider making a "donation" to me via PayPal. I spend a lot of free time
-creating free software, and would appreciate any support you'd care to offer.
-
-Please note that B<I am not suggesting that you must do this> in order for me
-to continue working on this particular software. I will continue to do so,
-inasmuch as I have in the past, for as long as it interests me.
-
-Similarly, a donation made in this way will probably not make me work on this
-software much more, unless I get so many donations that I can consider working
-on free software full time (let's all have a chuckle at that together).
-
-To donate, log into PayPal and send money to autarch@urth.org, or use the
-button at L<http://www.urth.org/~autarch/fs-donation.html>.
-
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Dave Rolsky Greg Oschwald Mark Fowler
+=for stopwords Dave Rolsky Greg Oschwald Mark Fowler Olaf Alders
 
 =over 4
 
@@ -1135,6 +1124,10 @@ Greg Oschwald <goschwald@maxmind.com>
 
 Mark Fowler <mark@twoshortplanks.com>
 
+=item *
+
+Olaf Alders <oalders@maxmind.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
